#define NEW csd_background_manager_new
#define START csd_background_manager_start
#define STOP csd_background_manager_stop
#define MANAGER CsdBackgroundManager
#include "csd-background-manager.h"

#include "test-plugin.h"
