#define NEW csd_automount_manager_new
#define START csd_automount_manager_start
#define STOP csd_automount_manager_stop
#define MANAGER CsdAutomountManager
#include "csd-automount-manager.h"

#include "test-plugin.h"
